@@ -33,12 +33,11 @@ describe 'heat::db::postgresql' do
     context "on #{os}" do
       let (:facts) do
         facts.merge(OSDefaults.get_facts({
-          :processorcount => 8,
           :concat_basedir => '/var/lib/puppet/concat'
         }))
       end
 
-      it_configures 'heat::db::postgresql'
+      it_behaves_like 'heat::db::postgresql'
     end
   end
 
