@@ -11,25 +11,26 @@ describe 'heat::logging' do
     {
       :logging_context_format_string => '%(asctime)s.%(msecs)03d %(process)d %(levelname)s %(name)s [%(request_id)s %(user_identity)s] %(instance)s%(message)s',
       :logging_default_format_string => '%(asctime)s.%(msecs)03d %(process)d %(levelname)s %(name)s [-] %(instance)s%(message)s',
-      :logging_debug_format_suffix => '%(funcName)s %(pathname)s:%(lineno)d',
-      :logging_exception_prefix => '%(asctime)s.%(msecs)03d %(process)d TRACE %(name)s %(instance)s',
-      :log_config_append => '/etc/heat/logging.conf',
-      :publish_errors => true,
+      :logging_debug_format_suffix   => '%(funcName)s %(pathname)s:%(lineno)d',
+      :logging_exception_prefix      => '%(asctime)s.%(msecs)03d %(process)d TRACE %(name)s %(instance)s',
+      :log_config_append             => '/etc/heat/logging.conf',
+      :publish_errors                => true,
       :default_log_levels => {
         'amqp' => 'WARN', 'amqplib' => 'WARN', 'boto' => 'WARN',
         'sqlalchemy' => 'WARN', 'suds' => 'INFO', 'iso8601' => 'WARN',
         'requests.packages.urllib3.connectionpool' => 'WARN' },
-     :fatal_deprecations => true,
-     :instance_format => '[instance: %(uuid)s] ',
-     :instance_uuid_format => '[instance: %(uuid)s] ',
-     :log_date_format => '%Y-%m-%d %H:%M:%S',
-     :use_syslog => true,
-     :use_json => true,
-     :use_journal => true,
-     :use_stderr => false,
-     :log_facility => 'LOG_FOO',
-     :log_dir => '/var/log',
-     :debug => true,
+     :fatal_deprecations             => true,
+     :instance_format                => '[instance: %(uuid)s] ',
+     :instance_uuid_format           => '[instance: %(uuid)s] ',
+     :log_date_format                => '%Y-%m-%d %H:%M:%S',
+     :use_syslog                     => true,
+     :use_json                       => true,
+     :use_journal                    => true,
+     :use_stderr                     => false,
+     :log_facility                   => 'LOG_FOO',
+     :log_dir                        => '/var/log',
+     :log_file                       => '/var/log/heat/heat.log',
+     :debug                          => true,
     }
   end
 
@@ -63,6 +64,7 @@ describe 'heat::logging' do
         :use_journal => '<SERVICE DEFAULT>',
         :use_stderr  => '<SERVICE DEFAULT>',
         :log_dir     => '/var/log/heat',
+        :log_file    => '<SERVICE DEFAULT>',
         :debug       => '<SERVICE DEFAULT>',
       )
     end
@@ -77,6 +79,7 @@ describe 'heat::logging' do
         :use_stderr          => false,
         :syslog_log_facility => 'LOG_FOO',
         :log_dir             => '/var/log',
+        :log_file            => '/var/log/heat/heat.log',
         :debug               => true,
       )
     end
